# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__autoscaling__v2beta2_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.api.resource import Quantity
from ...apimachinery.pkg.apis.meta.v1 import LabelSelector, ListMeta, ObjectMeta, Time


@dataclass(slots=True, kw_only=True, frozen=True)
class CrossVersionObjectReference(LazyLoadModel):
    kind: str
    name: str
    apiVersion: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HPAScalingPolicy(LazyLoadModel):
    periodSeconds: int
    type: str
    value: int


@dataclass(slots=True, kw_only=True, frozen=True)
class HPAScalingRules(LazyLoadModel):
    policies: List[HPAScalingPolicy] | None = None
    selectPolicy: str | None = None
    stabilizationWindowSeconds: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerBehavior(LazyLoadModel):
    scaleDown: HPAScalingRules | None = None
    scaleUp: HPAScalingRules | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerCondition(LazyLoadModel):
    status: str
    type: str
    lastTransitionTime: Time | None = None
    message: str | None = None
    reason: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class MetricTarget(LazyLoadModel):
    type: str
    averageUtilization: int | None = None
    averageValue: Quantity | None = None
    value: Quantity | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class MetricValueStatus(LazyLoadModel):
    averageUtilization: int | None = None
    averageValue: Quantity | None = None
    value: Quantity | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceMetricSource(LazyLoadModel):
    name: str
    target: MetricTarget


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceMetricStatus(LazyLoadModel):
    current: MetricValueStatus
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class ContainerResourceMetricSource(LazyLoadModel):
    container: str
    name: str
    target: MetricTarget


@dataclass(slots=True, kw_only=True, frozen=True)
class ContainerResourceMetricStatus(LazyLoadModel):
    container: str
    current: MetricValueStatus
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class MetricIdentifier(LazyLoadModel):
    name: str
    selector: LabelSelector | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ObjectMetricSource(LazyLoadModel):
    describedObject: CrossVersionObjectReference
    metric: MetricIdentifier
    target: MetricTarget


@dataclass(slots=True, kw_only=True, frozen=True)
class ObjectMetricStatus(LazyLoadModel):
    current: MetricValueStatus
    describedObject: CrossVersionObjectReference
    metric: MetricIdentifier


@dataclass(slots=True, kw_only=True, frozen=True)
class PodsMetricSource(LazyLoadModel):
    metric: MetricIdentifier
    target: MetricTarget


@dataclass(slots=True, kw_only=True, frozen=True)
class PodsMetricStatus(LazyLoadModel):
    current: MetricValueStatus
    metric: MetricIdentifier


@dataclass(slots=True, kw_only=True, frozen=True)
class ExternalMetricSource(LazyLoadModel):
    metric: MetricIdentifier
    target: MetricTarget


@dataclass(slots=True, kw_only=True, frozen=True)
class ExternalMetricStatus(LazyLoadModel):
    current: MetricValueStatus
    metric: MetricIdentifier


@dataclass(slots=True, kw_only=True, frozen=True)
class MetricSpec(LazyLoadModel):
    type: str
    containerResource: ContainerResourceMetricSource | None = None
    external: ExternalMetricSource | None = None
    object: ObjectMetricSource | None = None
    pods: PodsMetricSource | None = None
    resource: ResourceMetricSource | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class MetricStatus(LazyLoadModel):
    type: str
    containerResource: ContainerResourceMetricStatus | None = None
    external: ExternalMetricStatus | None = None
    object: ObjectMetricStatus | None = None
    pods: PodsMetricStatus | None = None
    resource: ResourceMetricStatus | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerSpec(LazyLoadModel):
    maxReplicas: int
    scaleTargetRef: CrossVersionObjectReference
    behavior: HorizontalPodAutoscalerBehavior | None = None
    metrics: List[MetricSpec] | None = None
    minReplicas: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerStatus(LazyLoadModel):
    currentReplicas: int
    desiredReplicas: int
    conditions: List[HorizontalPodAutoscalerCondition] | None = None
    currentMetrics: List[MetricStatus] | None = None
    lastScaleTime: Time | None = None
    observedGeneration: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscaler(K8sResource):
    apiVersion: ClassVar[str] = 'autoscaling/v2beta2'
    kind: ClassVar[str] = 'HorizontalPodAutoscaler'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    spec: HorizontalPodAutoscalerSpec | None = None
    status: HorizontalPodAutoscalerStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers'
    )
    plural_: ClassVar[str] = 'horizontalpodautoscalers'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'autoscaling'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerList(LazyLoadModel):
    items: List[HorizontalPodAutoscaler]
    apiVersion: str = 'autoscaling/v2beta2'
    kind: str = 'HorizontalPodAutoscalerList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import AWSElasticBlockStoreVolumeSource, Affinity, AppArmorProfile, AttachedVolume, AzureDiskVolumeSource, AzureFilePersistentVolumeSource, AzureFileVolumeSource, Binding, CSIPersistentVolumeSource, CSIVolumeSource, Capabilities, CephFSPersistentVolumeSource, CephFSVolumeSource, CinderPersistentVolumeSource, CinderVolumeSource, ClientIPConfig, ClusterTrustBundleProjection, ComponentCondition, ComponentStatus, ComponentStatusList, ConfigMap, ConfigMapEnvSource, ConfigMapKeySelector, ConfigMapList, ConfigMapNodeConfigSource, ConfigMapProjection, ConfigMapVolumeSource, Container, ContainerExtendedResourceRequest, ContainerImage, ContainerPort, ContainerResizePolicy, ContainerRestartRule, ContainerRestartRuleOnExitCodes, ContainerState, ContainerStateRunning, ContainerStateTerminated, ContainerStateWaiting, ContainerStatus, ContainerUser, DaemonEndpoint, DownwardAPIProjection, DownwardAPIVolumeFile, DownwardAPIVolumeSource, EmptyDirVolumeSource, EndpointAddress, EndpointPort, EndpointSubset, Endpoints, EndpointsList, EnvFromSource, EnvVar, EnvVarSource, EphemeralContainer, EphemeralVolumeSource, Event, EventList, EventSeries, EventSource, ExecAction, FCVolumeSource, FileKeySelector, FlexPersistentVolumeSource, FlexVolumeSource, FlockerVolumeSource, GCEPersistentDiskVolumeSource, GRPCAction, GitRepoVolumeSource, GlusterfsPersistentVolumeSource, GlusterfsVolumeSource, HTTPGetAction, HTTPHeader, HostAlias, HostIP, HostPathVolumeSource, ISCSIPersistentVolumeSource, ISCSIVolumeSource, ImageVolumeSource, KeyToPath, Lifecycle, LifecycleHandler, LimitRange, LimitRangeItem, LimitRangeList, LimitRangeSpec, LinuxContainerUser, LoadBalancerIngress, LoadBalancerStatus, LocalObjectReference, LocalVolumeSource, ModifyVolumeStatus, NFSVolumeSource, Namespace, NamespaceCondition, NamespaceList, NamespaceSpec, NamespaceStatus, Node, NodeAddress, NodeAffinity, NodeCondition, NodeConfigSource, NodeConfigStatus, NodeDaemonEndpoints, NodeFeatures, NodeList, NodeRuntimeHandler, NodeRuntimeHandlerFeatures, NodeSelector, NodeSelectorRequirement, NodeSelectorTerm, NodeSpec, NodeStatus, NodeSwapStatus, NodeSystemInfo, ObjectFieldSelector, ObjectReference, PersistentVolume, PersistentVolumeClaim, PersistentVolumeClaimCondition, PersistentVolumeClaimList, PersistentVolumeClaimSpec, PersistentVolumeClaimStatus, PersistentVolumeClaimTemplate, PersistentVolumeClaimVolumeSource, PersistentVolumeList, PersistentVolumeSpec, PersistentVolumeStatus, PhotonPersistentDiskVolumeSource, Pod, PodAffinity, PodAffinityTerm, PodAntiAffinity, PodCertificateProjection, PodCondition, PodDNSConfig, PodDNSConfigOption, PodExtendedResourceClaimStatus, PodIP, PodList, PodOS, PodReadinessGate, PodResourceClaim, PodResourceClaimStatus, PodSchedulingGate, PodSecurityContext, PodSpec, PodStatus, PodTemplate, PodTemplateList, PodTemplateSpec, PortStatus, PortworxVolumeSource, PreferredSchedulingTerm, Probe, ProjectedVolumeSource, QuobyteVolumeSource, RBDPersistentVolumeSource, RBDVolumeSource, ReplicationController, ReplicationControllerCondition, ReplicationControllerList, ReplicationControllerSpec, ReplicationControllerStatus, ResourceClaim, ResourceFieldSelector, ResourceHealth, ResourceQuota, ResourceQuotaList, ResourceQuotaSpec, ResourceQuotaStatus, ResourceRequirements, ResourceStatus, SELinuxOptions, ScaleIOPersistentVolumeSource, ScaleIOVolumeSource, ScopeSelector, ScopedResourceSelectorRequirement, SeccompProfile, Secret, SecretEnvSource, SecretKeySelector, SecretList, SecretProjection, SecretReference, SecretVolumeSource, SecurityContext, Service, ServiceAccount, ServiceAccountList, ServiceAccountTokenProjection, ServiceList, ServicePort, ServiceSpec, ServiceStatus, SessionAffinityConfig, SleepAction, StorageOSPersistentVolumeSource, StorageOSVolumeSource, Sysctl, TCPSocketAction, Taint, Toleration, TopologySpreadConstraint, TypedLocalObjectReference, TypedObjectReference, Volume, VolumeDevice, VolumeMount, VolumeMountStatus, VolumeNodeAffinity, VolumeProjection, VolumeResourceRequirements, VsphereVirtualDiskVolumeSource, WeightedPodAffinityTerm, WindowsSecurityContextOptions




__all__ = ['AWSElasticBlockStoreVolumeSource', 'Affinity', 'AppArmorProfile', 'AttachedVolume', 'AzureDiskVolumeSource', 'AzureFilePersistentVolumeSource', 'AzureFileVolumeSource', 'Binding', 'CSIPersistentVolumeSource', 'CSIVolumeSource', 'Capabilities', 'CephFSPersistentVolumeSource', 'CephFSVolumeSource', 'CinderPersistentVolumeSource', 'CinderVolumeSource', 'ClientIPConfig', 'ClusterTrustBundleProjection', 'ComponentCondition', 'ComponentStatus', 'ComponentStatusList', 'ConfigMap', 'ConfigMapEnvSource', 'ConfigMapKeySelector', 'ConfigMapList', 'ConfigMapNodeConfigSource', 'ConfigMapProjection', 'ConfigMapVolumeSource', 'Container', 'ContainerExtendedResourceRequest', 'ContainerImage', 'ContainerPort', 'ContainerResizePolicy', 'ContainerRestartRule', 'ContainerRestartRuleOnExitCodes', 'ContainerState', 'ContainerStateRunning', 'ContainerStateTerminated', 'ContainerStateWaiting', 'ContainerStatus', 'ContainerUser', 'DaemonEndpoint', 'DownwardAPIProjection', 'DownwardAPIVolumeFile', 'DownwardAPIVolumeSource', 'EmptyDirVolumeSource', 'EndpointAddress', 'EndpointPort', 'EndpointSubset', 'Endpoints', 'EndpointsList', 'EnvFromSource', 'EnvVar', 'EnvVarSource', 'EphemeralContainer', 'EphemeralVolumeSource', 'Event', 'EventList', 'EventSeries', 'EventSource', 'ExecAction', 'FCVolumeSource', 'FileKeySelector', 'FlexPersistentVolumeSource', 'FlexVolumeSource', 'FlockerVolumeSource', 'GCEPersistentDiskVolumeSource', 'GRPCAction', 'GitRepoVolumeSource', 'GlusterfsPersistentVolumeSource', 'GlusterfsVolumeSource', 'HTTPGetAction', 'HTTPHeader', 'HostAlias', 'HostIP', 'HostPathVolumeSource', 'ISCSIPersistentVolumeSource', 'ISCSIVolumeSource', 'ImageVolumeSource', 'KeyToPath', 'Lifecycle', 'LifecycleHandler', 'LimitRange', 'LimitRangeItem', 'LimitRangeList', 'LimitRangeSpec', 'LinuxContainerUser', 'LoadBalancerIngress', 'LoadBalancerStatus', 'LocalObjectReference', 'LocalVolumeSource', 'ModifyVolumeStatus', 'NFSVolumeSource', 'Namespace', 'NamespaceCondition', 'NamespaceList', 'NamespaceSpec', 'NamespaceStatus', 'Node', 'NodeAddress', 'NodeAffinity', 'NodeCondition', 'NodeConfigSource', 'NodeConfigStatus', 'NodeDaemonEndpoints', 'NodeFeatures', 'NodeList', 'NodeRuntimeHandler', 'NodeRuntimeHandlerFeatures', 'NodeSelector', 'NodeSelectorRequirement', 'NodeSelectorTerm', 'NodeSpec', 'NodeStatus', 'NodeSwapStatus', 'NodeSystemInfo', 'ObjectFieldSelector', 'ObjectReference', 'PersistentVolume', 'PersistentVolumeClaim', 'PersistentVolumeClaimCondition', 'PersistentVolumeClaimList', 'PersistentVolumeClaimSpec', 'PersistentVolumeClaimStatus', 'PersistentVolumeClaimTemplate', 'PersistentVolumeClaimVolumeSource', 'PersistentVolumeList', 'PersistentVolumeSpec', 'PersistentVolumeStatus', 'PhotonPersistentDiskVolumeSource', 'Pod', 'PodAffinity', 'PodAffinityTerm', 'PodAntiAffinity', 'PodCertificateProjection', 'PodCondition', 'PodDNSConfig', 'PodDNSConfigOption', 'PodExtendedResourceClaimStatus', 'PodIP', 'PodList', 'PodOS', 'PodReadinessGate', 'PodResourceClaim', 'PodResourceClaimStatus', 'PodSchedulingGate', 'PodSecurityContext', 'PodSpec', 'PodStatus', 'PodTemplate', 'PodTemplateList', 'PodTemplateSpec', 'PortStatus', 'PortworxVolumeSource', 'PreferredSchedulingTerm', 'Probe', 'ProjectedVolumeSource', 'QuobyteVolumeSource', 'RBDPersistentVolumeSource', 'RBDVolumeSource', 'ReplicationController', 'ReplicationControllerCondition', 'ReplicationControllerList', 'ReplicationControllerSpec', 'ReplicationControllerStatus', 'ResourceClaim', 'ResourceFieldSelector', 'ResourceHealth', 'ResourceQuota', 'ResourceQuotaList', 'ResourceQuotaSpec', 'ResourceQuotaStatus', 'ResourceRequirements', 'ResourceStatus', 'SELinuxOptions', 'ScaleIOPersistentVolumeSource', 'ScaleIOVolumeSource', 'ScopeSelector', 'ScopedResourceSelectorRequirement', 'SeccompProfile', 'Secret', 'SecretEnvSource', 'SecretKeySelector', 'SecretList', 'SecretProjection', 'SecretReference', 'SecretVolumeSource', 'SecurityContext', 'Service', 'ServiceAccount', 'ServiceAccountList', 'ServiceAccountTokenProjection', 'ServiceList', 'ServicePort', 'ServiceSpec', 'ServiceStatus', 'SessionAffinityConfig', 'SleepAction', 'StorageOSPersistentVolumeSource', 'StorageOSVolumeSource', 'Sysctl', 'TCPSocketAction', 'Taint', 'Toleration', 'TopologySpreadConstraint', 'TypedLocalObjectReference', 'TypedObjectReference', 'Volume', 'VolumeDevice', 'VolumeMount', 'VolumeMountStatus', 'VolumeNodeAffinity', 'VolumeProjection', 'VolumeResourceRequirements', 'VsphereVirtualDiskVolumeSource', 'WeightedPodAffinityTerm', 'WindowsSecurityContextOptions']




# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__autoscaling__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *


@dataclass(slots=True, kw_only=True, frozen=True)
class RawExtension(LazyLoadModel):
    pass



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__apps__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ObjectMeta


@dataclass(slots=True, kw_only=True, frozen=True)
class ScaleSpec(LazyLoadModel):
    replicas: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ScaleStatus(LazyLoadModel):
    replicas: int
    selector: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class Scale(LazyLoadModel):
    apiVersion: str = 'autoscaling/v1'
    kind: str = 'Scale'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    spec: ScaleSpec | None = None
    status: ScaleStatus | None = None



# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha2 import LeaseCandidate, LeaseCandidateList, LeaseCandidateSpec




__all__ = ['LeaseCandidate', 'LeaseCandidateList', 'LeaseCandidateSpec']




# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha3 import CELDeviceSelector, DeviceSelector, DeviceTaint, DeviceTaintRule, DeviceTaintRuleList, DeviceTaintRuleSpec, DeviceTaintSelector




__all__ = ['CELDeviceSelector', 'DeviceSelector', 'DeviceTaint', 'DeviceTaintRule', 'DeviceTaintRuleList', 'DeviceTaintRuleSpec', 'DeviceTaintSelector']




# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import PodDisruptionBudget, PodDisruptionBudgetList, PodDisruptionBudgetSpec, PodDisruptionBudgetStatus




__all__ = ['PodDisruptionBudget', 'PodDisruptionBudgetList', 'PodDisruptionBudgetSpec', 'PodDisruptionBudgetStatus']




from typing import Literal
try:
    from enum import StrEnum  # Python 3.11+
except ImportError:
    from enum import Enum
    class StrEnum(str, Enum):
        pass


# We do not add None to scalars because it makes no sense for our dynamic type loading.
# We will never have a field of None type in practice, but may receive None as a result of get_origin() call,
# which can be misleading.
SCALAR_TYPES = [str, int, float, bool, complex, bytes, bytearray, Literal]


class PatchRequestType(StrEnum):
    _legacy_json = "application/json"  # Swagger schema legacy
    cbor = "application/apply-patch+cbor"
    apply = 'application/apply-patch+yaml'
    json = 'application/json-patch+json'
    merge = 'application/merge-patch+json'
    strategic_merge = 'application/strategic-merge-patch+json'


class FieldPatchStrategy(StrEnum):
    retainKeys = "retainKeys"
    merge = "merge"
    replace = "replace"


PATCH_MERGE_KEY = 'x-kubernetes-patch-merge-key'
PATCH_STRATEGY = 'x-kubernetes-patch-strategy'

EXCLUDE_FIELD_META_KEY = "exclude_from_dict"



from __future__ import annotations

import importlib
import inspect
import pkgutil
from dataclasses import is_dataclass, MISSING
from typing import Dict, Tuple, Optional, Type, Any

from .loader import LazyLoadModel
from .resource import K8sResource, K8sResourceList


__ALL_RESOURCES: Dict[Tuple[str, str], Type[LazyLoadModel]] = {}

# One-time guard
__INDEX_BUILT: bool = False


def __maybe_get_model_key(cls: Type[Any]) -> Optional[Tuple[str, str]]:
    """
    Return (apiVersion, kind) if both exist as strings.

    Supports:
    - ClassVar[str] / plain class attributes
    - dataclass defaults, including slots=True dataclasses
    """
    # 1. First try plain/classvar attributes
    v = getattr(cls, "apiVersion", None)
    k = getattr(cls, "kind", None)
    if isinstance(v, str) and isinstance(k, str):
        return v, k

    # 2. Fallback: dataclass fields (works for slots / non-slots)
    dc_fields = getattr(cls, "__dataclass_fields__", None)
    if isinstance(dc_fields, dict):
        v_field = dc_fields.get("apiVersion")
        k_field = dc_fields.get("kind")

        def _get_str_default(f):
            if f is None:
                return None
            default = f.default
            if default is MISSING:
                factory = getattr(f, "default_factory", MISSING)
                if factory is not MISSING:
                    default = factory()
            return default if isinstance(default, str) else None

        v_default = _get_str_default(v_field)
        k_default = _get_str_default(k_field)

        if v_default is not None and k_default is not None:
            return v_default, k_default

    return None


def __register_from_module(module) -> None:
    """
    Inspect a module and register any dataclasses that have both apiVersion and kind.
    Only classes defined in the module itself are considered (not re-exports).
    """
    for obj in vars(module).values():
        if inspect.isclass(obj) and is_dataclass(obj) and obj.__module__ == module.__name__:
            model_key = __maybe_get_model_key(obj)
            if model_key:
                obj: Type[K8sResource]
                __ALL_RESOURCES.setdefault(model_key, obj)


def __discover_all_submodules() -> None:
    """Import all submodules of this package."""
    if "__path__" not in globals():
        # Not a package
        return
    prefix = __name__ + "."
    for _finder, modname, _ispkg in pkgutil.walk_packages(__path__, prefix=prefix):
        # Skip private files
        if modname.split(".")[-1].startswith("_"):
            continue

        mod = importlib.import_module(modname)
        __register_from_module(mod)


def __build_index() -> None:
    """
    Build the DATACLASSES_BY_GVK index once.
    """
    global __INDEX_BUILT
    if __INDEX_BUILT:
        return
    __discover_all_submodules()
    __INDEX_BUILT = True


__build_index()


def get_model(api_version: str, kind: str) -> Type[LazyLoadModel]:
    return __ALL_RESOURCES.get((api_version, kind))


def get_k8s_resource_model(api_version: str, kind: str) -> Type[K8sResource] | None:
    model = get_model(api_version, kind)
    if model and issubclass(model, K8sResource):
        return model
    return None


def get_model_by_body(body: Dict) -> Type[LazyLoadModel]:
    api_version, kind = body.get("apiVersion"), body.get("kind")
    return get_model(api_version, kind)


__all__ = ["get_k8s_resource_model", "get_model", "get_model_by_body", "K8sResource", "K8sResourceList"]



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__flowcontrol.apiserver.k8s.io__v1beta1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta, Time


@dataclass(slots=True, kw_only=True, frozen=True)
class FlowDistinguisherMethod(LazyLoadModel):
    type: str


@dataclass(slots=True, kw_only=True, frozen=True)
class GroupSubject(LazyLoadModel):
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class NonResourcePolicyRule(LazyLoadModel):
    nonResourceURLs: List[str]
    verbs: List[str]


@dataclass(slots=True, kw_only=True, frozen=True)
class PriorityLevelConfigurationReference(LazyLoadModel):
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class QueuingConfiguration(LazyLoadModel):
    handSize: int | None = None
    queueLengthLimit: int | None = None
    queues: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourcePolicyRule(LazyLoadModel):
    apiGroups: List[str]
    resources: List[str]
    verbs: List[str]
    clusterScope: bool | None = None
    namespaces: List[str] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ServiceAccountSubject(LazyLoadModel):
    name: str
    namespace: str


@dataclass(slots=True, kw_only=True, frozen=True)
class UserSubject(LazyLoadModel):
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class FlowSchemaCondition(LazyLoadModel):
    lastTransitionTime: Time | None = None
    message: str | None = None
    reason: str | None = None
    status: str | None = None
    type: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class FlowSchemaStatus(LazyLoadModel):
    conditions: List[FlowSchemaCondition] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class LimitResponse(LazyLoadModel):
    type: str
    queuing: QueuingConfiguration | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class LimitedPriorityLevelConfiguration(LazyLoadModel):
    assuredConcurrencyShares: int | None = None
    limitResponse: LimitResponse | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PriorityLevelConfigurationCondition(LazyLoadModel):
    lastTransitionTime: Time | None = None
    message: str | None = None
    reason: str | None = None
    status: str | None = None
    type: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PriorityLevelConfigurationSpec(LazyLoadModel):
    type: str
    limited: LimitedPriorityLevelConfiguration | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PriorityLevelConfigurationStatus(LazyLoadModel):
    conditions: List[PriorityLevelConfigurationCondition] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class Subject(LazyLoadModel):
    kind: str
    group: GroupSubject | None = None
    serviceAccount: ServiceAccountSubject | None = None
    user: UserSubject | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PolicyRulesWithSubjects(LazyLoadModel):
    subjects: List[Subject]
    nonResourceRules: List[NonResourcePolicyRule] | None = None
    resourceRules: List[ResourcePolicyRule] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PriorityLevelConfiguration(K8sResource):
    apiVersion: ClassVar[str] = 'flowcontrol.apiserver.k8s.io/v1beta1'
    kind: ClassVar[str] = 'PriorityLevelConfiguration'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    spec: PriorityLevelConfigurationSpec | None = None
    status: PriorityLevelConfigurationStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations'
    )
    plural_: ClassVar[str] = 'prioritylevelconfigurations'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'flowcontrol.apiserver.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class PriorityLevelConfigurationList(LazyLoadModel):
    items: List[PriorityLevelConfiguration]
    apiVersion: str = 'flowcontrol.apiserver.k8s.io/v1beta1'
    kind: str = 'PriorityLevelConfigurationList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class FlowSchemaSpec(LazyLoadModel):
    priorityLevelConfiguration: PriorityLevelConfigurationReference
    distinguisherMethod: FlowDistinguisherMethod | None = None
    matchingPrecedence: int | None = None
    rules: List[PolicyRulesWithSubjects] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class FlowSchema(K8sResource):
    apiVersion: ClassVar[str] = 'flowcontrol.apiserver.k8s.io/v1beta1'
    kind: ClassVar[str] = 'FlowSchema'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    spec: FlowSchemaSpec | None = None
    status: FlowSchemaStatus | None = None
    api_path_: ClassVar[str] = 'apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas'
    plural_: ClassVar[str] = 'flowschemas'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'flowcontrol.apiserver.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class FlowSchemaList(LazyLoadModel):
    items: List[FlowSchema]
    apiVersion: str = 'flowcontrol.apiserver.k8s.io/v1beta1'
    kind: str = 'FlowSchemaList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import UserInfo
from .v1beta1 import SelfSubjectReview, SelfSubjectReviewStatus




__all__ = ['UserInfo', 'SelfSubjectReview', 'SelfSubjectReviewStatus']




# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import Endpoint, EndpointConditions, EndpointHints, EndpointPort, EndpointSlice, EndpointSliceList, ForNode, ForZone




__all__ = ['Endpoint', 'EndpointConditions', 'EndpointHints', 'EndpointPort', 'EndpointSlice', 'EndpointSliceList', 'ForNode', 'ForZone']




# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha1 import GroupVersionResource, MigrationCondition, StorageVersionMigration, StorageVersionMigrationList, StorageVersionMigrationSpec, StorageVersionMigrationStatus




__all__ = ['GroupVersionResource', 'MigrationCondition', 'StorageVersionMigration', 'StorageVersionMigrationList', 'StorageVersionMigrationSpec', 'StorageVersionMigrationStatus']




# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha2 import AllocationResult, DriverAllocationResult, DriverRequests, NamedResourcesAllocationResult, NamedResourcesAttribute, NamedResourcesFilter, NamedResourcesInstance, NamedResourcesIntSlice, NamedResourcesRequest, NamedResourcesResources, NamedResourcesStringSlice, PodSchedulingContext, PodSchedulingContextList, PodSchedulingContextSpec, PodSchedulingContextStatus, ResourceClaim, ResourceClaimConsumerReference, ResourceClaimList, ResourceClaimParameters, ResourceClaimParametersList, ResourceClaimParametersReference, ResourceClaimSchedulingStatus, ResourceClaimSpec, ResourceClaimStatus, ResourceClaimTemplate, ResourceClaimTemplateList, ResourceClaimTemplateSpec, ResourceClass, ResourceClassList, ResourceClassParameters, ResourceClassParametersList, ResourceClassParametersReference, ResourceFilter, ResourceHandle, ResourceRequest, ResourceSlice, ResourceSliceList, StructuredResourceHandle, VendorParameters




__all__ = ['AllocationResult', 'DriverAllocationResult', 'DriverRequests', 'NamedResourcesAllocationResult', 'NamedResourcesAttribute', 'NamedResourcesFilter', 'NamedResourcesInstance', 'NamedResourcesIntSlice', 'NamedResourcesRequest', 'NamedResourcesResources', 'NamedResourcesStringSlice', 'PodSchedulingContext', 'PodSchedulingContextList', 'PodSchedulingContextSpec', 'PodSchedulingContextStatus', 'ResourceClaim', 'ResourceClaimConsumerReference', 'ResourceClaimList', 'ResourceClaimParameters', 'ResourceClaimParametersList', 'ResourceClaimParametersReference', 'ResourceClaimSchedulingStatus', 'ResourceClaimSpec', 'ResourceClaimStatus', 'ResourceClaimTemplate', 'ResourceClaimTemplateList', 'ResourceClaimTemplateSpec', 'ResourceClass', 'ResourceClassList', 'ResourceClassParameters', 'ResourceClassParametersList', 'ResourceClassParametersReference', 'ResourceFilter', 'ResourceHandle', 'ResourceRequest', 'ResourceSlice', 'ResourceSliceList', 'StructuredResourceHandle', 'VendorParameters']




# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  version_openapi.json

from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *


@dataclass(slots=True, kw_only=True, frozen=True)
class Info(LazyLoadModel):
    buildDate: str
    compiler: str
    gitCommit: str
    gitTreeState: str
    gitVersion: str
    goVersion: str
    major: str
    minor: str
    platform: str
    emulationMajor: str | None = None
    emulationMinor: str | None = None
    minCompatibilityMajor: str | None = None
    minCompatibilityMinor: str | None = None



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__node.k8s.io__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, Dict, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.api.resource import Quantity
from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta
from ..core.v1 import Toleration


@dataclass(slots=True, kw_only=True, frozen=True)
class Scheduling(LazyLoadModel):
    nodeSelector: Dict[str, str] | None = None
    tolerations: List[Toleration] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class Overhead(LazyLoadModel):
    podFixed: Dict[str, Quantity] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class RuntimeClass(K8sResource):
    handler: str
    apiVersion: ClassVar[str] = 'node.k8s.io/v1'
    kind: ClassVar[str] = 'RuntimeClass'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    overhead: Overhead | None = None
    scheduling: Scheduling | None = None
    api_path_: ClassVar[str] = 'apis/node.k8s.io/v1/runtimeclasses'
    plural_: ClassVar[str] = 'runtimeclasses'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'node.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+cbor',
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class RuntimeClassList(LazyLoadModel):
    items: List[RuntimeClass]
    apiVersion: str = 'node.k8s.io/v1'
    kind: str = 'RuntimeClassList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__batch__v1beta1_openapi.json

from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import LabelSelector
from ..core.v1 import PodTemplateSpec


@dataclass(slots=True, kw_only=True, frozen=True)
class JobSpec(LazyLoadModel):
    template: PodTemplateSpec
    activeDeadlineSeconds: int | None = None
    backoffLimit: int | None = None
    completionMode: str | None = None
    completions: int | None = None
    manualSelector: bool | None = None
    parallelism: int | None = None
    selector: LabelSelector | None = None
    suspend: bool | None = None
    ttlSecondsAfterFinished: int | None = None



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__apiextensions.k8s.io__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import Any, ClassVar, Dict, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from .....apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta, Time


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceColumnDefinition(LazyLoadModel):
    jsonPath: str
    name: str
    type: str
    description: str | None = None
    format: str | None = None
    priority: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinitionNames(LazyLoadModel):
    kind: str
    plural: str
    categories: List[str] | None = None
    listKind: str | None = None
    shortNames: List[str] | None = None
    singular: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceSubresourceScale(LazyLoadModel):
    specReplicasPath: str
    statusReplicasPath: str
    labelSelectorPath: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceSubresourceStatus(LazyLoadModel):
    pass


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceSubresources(LazyLoadModel):
    scale: CustomResourceSubresourceScale | None = None
    status: CustomResourceSubresourceStatus | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ExternalDocumentation(LazyLoadModel):
    description: str | None = None
    url: str | None = None


JSON = Any


JSONSchemaPropsOrArray = Any


JSONSchemaPropsOrBool = Any


JSONSchemaPropsOrStringArray = Any


@dataclass(slots=True, kw_only=True, frozen=True)
class SelectableField(LazyLoadModel):
    jsonPath: str


@dataclass(slots=True, kw_only=True, frozen=True)
class ServiceReference(LazyLoadModel):
    name: str
    namespace: str
    path: str | None = None
    port: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ValidationRule(LazyLoadModel):
    rule: str
    fieldPath: str | None = None
    message: str | None = None
    messageExpression: str | None = None
    optionalOldSelf: bool | None = None
    reason: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class WebhookClientConfig(LazyLoadModel):
    caBundle: str | None = None
    service: ServiceReference | None = None
    url: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class WebhookConversion(LazyLoadModel):
    conversionReviewVersions: List[str]
    clientConfig: WebhookClientConfig | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceConversion(LazyLoadModel):
    strategy: str
    webhook: WebhookConversion | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinitionCondition(LazyLoadModel):
    status: str
    type: str
    lastTransitionTime: Time | None = None
    message: str | None = None
    reason: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinitionStatus(LazyLoadModel):
    acceptedNames: CustomResourceDefinitionNames | None = None
    conditions: List[CustomResourceDefinitionCondition] | None = None
    storedVersions: List[str] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class JSONSchemaProps(LazyLoadModel):
    field_ref: str | None = None
    field_schema: str | None = None
    additionalItems: JSONSchemaPropsOrBool | None = None
    additionalProperties: JSONSchemaPropsOrBool | None = None
    allOf: List[JSONSchemaProps] | None = None
    anyOf: List[JSONSchemaProps] | None = None
    default: JSON | None = None
    definitions: Dict[str, JSONSchemaProps] | None = None
    dependencies: Dict[str, JSONSchemaPropsOrStringArray] | None = None
    description: str | None = None
    enum: List[JSON] | None = None
    example: JSON | None = None
    exclusiveMaximum: bool | None = None
    exclusiveMinimum: bool | None = None
    externalDocs: ExternalDocumentation | None = None
    format: str | None = None
    id: str | None = None
    items: JSONSchemaPropsOrArray | None = None
    maxItems: int | None = None
    maxLength: int | None = None
    maxProperties: int | None = None
    maximum: float | None = None
    minItems: int | None = None
    minLength: int | None = None
    minProperties: int | None = None
    minimum: float | None = None
    multipleOf: float | None = None
    not_: JSONSchemaProps | None = None
    nullable: bool | None = None
    oneOf: List[JSONSchemaProps] | None = None
    pattern: str | None = None
    patternProperties: Dict[str, JSONSchemaProps] | None = None
    properties: Dict[str, JSONSchemaProps] | None = None
    required: List[str] | None = None
    title: str | None = None
    type: str | None = None
    uniqueItems: bool | None = None
    x_kubernetes_embedded_resource: bool | None = None
    x_kubernetes_int_or_string: bool | None = None
    x_kubernetes_list_map_keys: List[str] | None = None
    x_kubernetes_list_type: str | None = None
    x_kubernetes_map_type: str | None = None
    x_kubernetes_preserve_unknown_fields: bool | None = None
    x_kubernetes_validations: List[ValidationRule] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceValidation(LazyLoadModel):
    openAPIV3Schema: JSONSchemaProps | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinitionVersion(LazyLoadModel):
    name: str
    served: bool
    storage: bool
    additionalPrinterColumns: List[CustomResourceColumnDefinition] | None = None
    deprecated: bool | None = None
    deprecationWarning: str | None = None
    schema_: CustomResourceValidation | None = None
    selectableFields: List[SelectableField] | None = None
    subresources: CustomResourceSubresources | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinitionSpec(LazyLoadModel):
    group: str
    names: CustomResourceDefinitionNames
    scope: str
    versions: List[CustomResourceDefinitionVersion]
    conversion: CustomResourceConversion | None = None
    preserveUnknownFields: bool | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinition(K8sResource):
    spec: CustomResourceDefinitionSpec
    apiVersion: ClassVar[str] = 'apiextensions.k8s.io/v1'
    kind: ClassVar[str] = 'CustomResourceDefinition'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    status: CustomResourceDefinitionStatus | None = None
    api_path_: ClassVar[str] = 'apis/apiextensions.k8s.io/v1/customresourcedefinitions'
    plural_: ClassVar[str] = 'customresourcedefinitions'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'apiextensions.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+cbor',
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class CustomResourceDefinitionList(LazyLoadModel):
    items: List[CustomResourceDefinition]
    apiVersion: str = 'apiextensions.k8s.io/v1'
    kind: str = 'CustomResourceDefinitionList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__resource.k8s.io__v1alpha1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta
from ..core.v1 import NodeSelector


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingSpec(LazyLoadModel):
    potentialNodes: List[str] | None = None
    selectedNode: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimConsumerReference(LazyLoadModel):
    name: str
    resource: str
    uid: str
    apiGroup: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimParametersReference(LazyLoadModel):
    kind: str
    name: str
    apiGroup: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimSchedulingStatus(LazyLoadModel):
    name: str | None = None
    unsuitableNodes: List[str] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimSpec(LazyLoadModel):
    resourceClassName: str
    allocationMode: str | None = None
    parametersRef: ResourceClaimParametersReference | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClassParametersReference(LazyLoadModel):
    kind: str
    name: str
    apiGroup: str | None = None
    namespace: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class AllocationResult(LazyLoadModel):
    availableOnNodes: NodeSelector | None = None
    resourceHandle: str | None = None
    shareable: bool | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingStatus(LazyLoadModel):
    resourceClaims: List[ResourceClaimSchedulingStatus] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimStatus(LazyLoadModel):
    allocation: AllocationResult | None = None
    deallocationRequested: bool | None = None
    driverName: str | None = None
    reservedFor: List[ResourceClaimConsumerReference] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PodScheduling(K8sResource):
    spec: PodSchedulingSpec
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha1'
    kind: ClassVar[str] = 'PodScheduling'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    status: PodSchedulingStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha1/namespaces/{namespace}/podschedulings'
    )
    plural_: ClassVar[str] = 'podschedulings'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingList(LazyLoadModel):
    items: List[PodScheduling]
    apiVersion: str = 'resource.k8s.io/v1alpha1'
    kind: str = 'PodSchedulingList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaim(K8sResource):
    spec: ResourceClaimSpec
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha1'
    kind: ClassVar[str] = 'ResourceClaim'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    status: ResourceClaimStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha1/namespaces/{namespace}/resourceclaims'
    )
    plural_: ClassVar[str] = 'resourceclaims'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimList(LazyLoadModel):
    items: List[ResourceClaim]
    apiVersion: str = 'resource.k8s.io/v1alpha1'
    kind: str = 'ResourceClaimList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimTemplateSpec(LazyLoadModel):
    spec: ResourceClaimSpec
    metadata: ObjectMeta | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClass(K8sResource):
    driverName: str
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha1'
    kind: ClassVar[str] = 'ResourceClass'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    parametersRef: ResourceClassParametersReference | None = None
    suitableNodes: NodeSelector | None = None
    api_path_: ClassVar[str] = 'apis/resource.k8s.io/v1alpha1/resourceclasses'
    plural_: ClassVar[str] = 'resourceclasses'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClassList(LazyLoadModel):
    items: List[ResourceClass]
    apiVersion: str = 'resource.k8s.io/v1alpha1'
    kind: str = 'ResourceClassList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimTemplate(K8sResource):
    spec: ResourceClaimTemplateSpec
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha1'
    kind: ClassVar[str] = 'ResourceClaimTemplate'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha1/namespaces/{namespace}/resourceclaimtemplates'
    )
    plural_: ClassVar[str] = 'resourceclaimtemplates'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimTemplateList(LazyLoadModel):
    items: List[ResourceClaimTemplate]
    apiVersion: str = 'resource.k8s.io/v1alpha1'
    kind: str = 'ResourceClaimTemplateList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__discovery.k8s.io__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, Dict, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta
from ..core.v1 import ObjectReference


@dataclass(slots=True, kw_only=True, frozen=True)
class EndpointConditions(LazyLoadModel):
    ready: bool | None = None
    serving: bool | None = None
    terminating: bool | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class EndpointPort(LazyLoadModel):
    appProtocol: str | None = None
    name: str | None = None
    port: int | None = None
    protocol: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ForNode(LazyLoadModel):
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class ForZone(LazyLoadModel):
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class EndpointHints(LazyLoadModel):
    forNodes: List[ForNode] | None = None
    forZones: List[ForZone] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class Endpoint(LazyLoadModel):
    addresses: List[str]
    conditions: EndpointConditions | None = None
    deprecatedTopology: Dict[str, str] | None = None
    hints: EndpointHints | None = None
    hostname: str | None = None
    nodeName: str | None = None
    targetRef: ObjectReference | None = None
    zone: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class EndpointSlice(K8sResource):
    addressType: str
    endpoints: List[Endpoint]
    apiVersion: ClassVar[str] = 'discovery.k8s.io/v1'
    kind: ClassVar[str] = 'EndpointSlice'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    ports: List[EndpointPort] | None = None
    api_path_: ClassVar[str] = (
        'apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices'
    )
    plural_: ClassVar[str] = 'endpointslices'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'discovery.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+cbor',
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class EndpointSliceList(LazyLoadModel):
    items: List[EndpointSlice]
    apiVersion: str = 'discovery.k8s.io/v1'
    kind: str = 'EndpointSliceList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__events.k8s.io__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ListMeta, MicroTime, ObjectMeta, Time
from ..core.v1 import EventSource, ObjectReference


@dataclass(slots=True, kw_only=True, frozen=True)
class EventSeries(LazyLoadModel):
    count: int
    lastObservedTime: MicroTime


@dataclass(slots=True, kw_only=True, frozen=True)
class Event(K8sResource):
    eventTime: MicroTime
    action: str | None = None
    apiVersion: ClassVar[str] = 'events.k8s.io/v1'
    deprecatedCount: int | None = None
    deprecatedFirstTimestamp: Time | None = None
    deprecatedLastTimestamp: Time | None = None
    deprecatedSource: EventSource | None = None
    kind: ClassVar[str] = 'Event'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    note: str | None = None
    reason: str | None = None
    regarding: ObjectReference | None = None
    related: ObjectReference | None = None
    reportingController: str | None = None
    reportingInstance: str | None = None
    series: EventSeries | None = None
    type: str | None = None
    api_path_: ClassVar[str] = 'apis/events.k8s.io/v1/namespaces/{namespace}/events'
    plural_: ClassVar[str] = 'events'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'events.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+cbor',
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class EventList(LazyLoadModel):
    items: List[Event]
    apiVersion: str = 'events.k8s.io/v1'
    kind: str = 'EventList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__resource.k8s.io__v1alpha2_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.api.resource import Quantity
from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta
from ...apimachinery.pkg.runtime import RawExtension
from ..core.v1 import NodeSelector


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesAllocationResult(LazyLoadModel):
    name: str


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesFilter(LazyLoadModel):
    selector: str


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesIntSlice(LazyLoadModel):
    ints: List[int]


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesRequest(LazyLoadModel):
    selector: str


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesStringSlice(LazyLoadModel):
    strings: List[str]


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingContextSpec(LazyLoadModel):
    potentialNodes: List[str] | None = None
    selectedNode: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimConsumerReference(LazyLoadModel):
    name: str
    resource: str
    uid: str
    apiGroup: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimParametersReference(LazyLoadModel):
    kind: str
    name: str
    apiGroup: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimSchedulingStatus(LazyLoadModel):
    name: str | None = None
    unsuitableNodes: List[str] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimSpec(LazyLoadModel):
    resourceClassName: str
    allocationMode: str | None = None
    parametersRef: ResourceClaimParametersReference | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClassParametersReference(LazyLoadModel):
    kind: str
    name: str
    apiGroup: str | None = None
    namespace: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceFilter(LazyLoadModel):
    driverName: str | None = None
    namedResources: NamedResourcesFilter | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class DriverAllocationResult(LazyLoadModel):
    namedResources: NamedResourcesAllocationResult | None = None
    vendorRequestParameters: RawExtension | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesAttribute(LazyLoadModel):
    name: str
    bool: bool | None = None
    int: int | None = None
    intSlice: NamedResourcesIntSlice | None = None
    quantity: Quantity | None = None
    string: str | None = None
    stringSlice: NamedResourcesStringSlice | None = None
    version: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesInstance(LazyLoadModel):
    name: str
    attributes: List[NamedResourcesAttribute] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class NamedResourcesResources(LazyLoadModel):
    instances: List[NamedResourcesInstance]


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingContextStatus(LazyLoadModel):
    resourceClaims: List[ResourceClaimSchedulingStatus] | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceRequest(LazyLoadModel):
    namedResources: NamedResourcesRequest | None = None
    vendorParameters: RawExtension | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class StructuredResourceHandle(LazyLoadModel):
    results: List[DriverAllocationResult]
    nodeName: str | None = None
    vendorClaimParameters: RawExtension | None = None
    vendorClassParameters: RawExtension | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class VendorParameters(LazyLoadModel):
    driverName: str | None = None
    parameters: RawExtension | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class DriverRequests(LazyLoadModel):
    driverName: str | None = None
    requests: List[ResourceRequest] | None = None
    vendorParameters: RawExtension | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingContext(K8sResource):
    spec: PodSchedulingContextSpec
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    kind: ClassVar[str] = 'PodSchedulingContext'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    status: PodSchedulingContextStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts'
    )
    plural_: ClassVar[str] = 'podschedulingcontexts'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class PodSchedulingContextList(LazyLoadModel):
    items: List[PodSchedulingContext]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'PodSchedulingContextList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimParameters(K8sResource):
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    driverRequests: List[DriverRequests] | None = None
    generatedFrom: ResourceClaimParametersReference | None = None
    kind: ClassVar[str] = 'ResourceClaimParameters'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    shareable: bool | None = None
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimparameters'
    )
    plural_: ClassVar[str] = 'resourceclaimparameters'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimParametersList(LazyLoadModel):
    items: List[ResourceClaimParameters]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'ResourceClaimParametersList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimTemplateSpec(LazyLoadModel):
    spec: ResourceClaimSpec
    metadata: ObjectMeta | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClass(K8sResource):
    driverName: str
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    kind: ClassVar[str] = 'ResourceClass'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    parametersRef: ResourceClassParametersReference | None = None
    structuredParameters: bool | None = None
    suitableNodes: NodeSelector | None = None
    api_path_: ClassVar[str] = 'apis/resource.k8s.io/v1alpha2/resourceclasses'
    plural_: ClassVar[str] = 'resourceclasses'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClassList(LazyLoadModel):
    items: List[ResourceClass]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'ResourceClassList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClassParameters(K8sResource):
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    filters: List[ResourceFilter] | None = None
    generatedFrom: ResourceClassParametersReference | None = None
    kind: ClassVar[str] = 'ResourceClassParameters'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    vendorParameters: List[VendorParameters] | None = None
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclassparameters'
    )
    plural_: ClassVar[str] = 'resourceclassparameters'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClassParametersList(LazyLoadModel):
    items: List[ResourceClassParameters]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'ResourceClassParametersList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceHandle(LazyLoadModel):
    data: str | None = None
    driverName: str | None = None
    structuredData: StructuredResourceHandle | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceSlice(K8sResource):
    driverName: str
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    kind: ClassVar[str] = 'ResourceSlice'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    namedResources: NamedResourcesResources | None = None
    nodeName: str | None = None
    api_path_: ClassVar[str] = 'apis/resource.k8s.io/v1alpha2/resourceslices'
    plural_: ClassVar[str] = 'resourceslices'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceSliceList(LazyLoadModel):
    items: List[ResourceSlice]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'ResourceSliceList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class AllocationResult(LazyLoadModel):
    availableOnNodes: NodeSelector | None = None
    resourceHandles: List[ResourceHandle] | None = None
    shareable: bool | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimStatus(LazyLoadModel):
    allocation: AllocationResult | None = None
    deallocationRequested: bool | None = None
    driverName: str | None = None
    reservedFor: List[ResourceClaimConsumerReference] = field(
        default_factory=list,
        metadata={
            'x-kubernetes-patch-strategy': 'merge',
            'x-kubernetes-patch-merge-key': 'uid',
        },
    )


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimTemplate(K8sResource):
    spec: ResourceClaimTemplateSpec
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    kind: ClassVar[str] = 'ResourceClaimTemplate'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates'
    )
    plural_: ClassVar[str] = 'resourceclaimtemplates'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimTemplateList(LazyLoadModel):
    items: List[ResourceClaimTemplate]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'ResourceClaimTemplateList'
    metadata: ListMeta = field(default_factory=ObjectMeta)


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaim(K8sResource):
    spec: ResourceClaimSpec
    apiVersion: ClassVar[str] = 'resource.k8s.io/v1alpha2'
    kind: ClassVar[str] = 'ResourceClaim'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    status: ResourceClaimStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims'
    )
    plural_: ClassVar[str] = 'resourceclaims'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'resource.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ResourceClaimList(LazyLoadModel):
    items: List[ResourceClaim]
    apiVersion: str = 'resource.k8s.io/v1alpha2'
    kind: str = 'ResourceClaimList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__autoscaling__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta, Time


@dataclass(slots=True, kw_only=True, frozen=True)
class CrossVersionObjectReference(LazyLoadModel):
    kind: str
    name: str
    apiVersion: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerSpec(LazyLoadModel):
    maxReplicas: int
    scaleTargetRef: CrossVersionObjectReference
    minReplicas: int | None = None
    targetCPUUtilizationPercentage: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerStatus(LazyLoadModel):
    currentReplicas: int
    desiredReplicas: int
    currentCPUUtilizationPercentage: int | None = None
    lastScaleTime: Time | None = None
    observedGeneration: int | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscaler(K8sResource):
    apiVersion: ClassVar[str] = 'autoscaling/v1'
    kind: ClassVar[str] = 'HorizontalPodAutoscaler'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    spec: HorizontalPodAutoscalerSpec | None = None
    status: HorizontalPodAutoscalerStatus | None = None
    api_path_: ClassVar[str] = (
        'apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers'
    )
    plural_: ClassVar[str] = 'horizontalpodautoscalers'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'autoscaling'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+cbor',
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class HorizontalPodAutoscalerList(LazyLoadModel):
    items: List[HorizontalPodAutoscaler]
    apiVersion: str = 'autoscaling/v1'
    kind: str = 'HorizontalPodAutoscalerList'
    metadata: ListMeta = field(default_factory=ObjectMeta)



from unittest import TestCase
from typing import Type, cast
import copy

from kube_models import get_k8s_resource_model
from kube_models.api_v1.io.k8s.apimachinery.pkg.apis.meta.v1 import ObjectMeta
from kube_models.api_v1.io.k8s.api.core.v1 import Secret


class UtilsTest(TestCase):
    def test_model_by_kind(self):
        secret = cast(Type[Secret], get_k8s_resource_model('v1', 'Secret'))
        self.assertEqual("v1", secret.apiVersion)
        self.assertEqual("Secret", secret.kind)
        self.assertIsNone(None, secret.group_)
        self.assertEqual("api/v1/namespaces/{namespace}/secrets", secret.api_path_)
        self.assertEqual("secrets", secret.plural_)

    def test_loading(self):
        secret_instance = Secret(
            metadata=ObjectMeta(name="some-secret", namespace="default"),
            data={"key": "value"}
        )
        self.assertEqual("v1", secret_instance.apiVersion)
        self.assertEqual("Secret", secret_instance.kind)

        dumped_secret = secret_instance.to_dict()
        self.assertEqual("v1", dumped_secret["apiVersion"])
        self.assertEqual("Secret", dumped_secret["kind"])

        loaded_secret = Secret.from_dict(dumped_secret)
        self.assertEqual(secret_instance, loaded_secret)

        copied_secret = copy.deepcopy(loaded_secret)
        self.assertEqual(secret_instance, copied_secret)



# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import CustomResourceColumnDefinition, CustomResourceConversion, CustomResourceDefinition, CustomResourceDefinitionCondition, CustomResourceDefinitionList, CustomResourceDefinitionNames, CustomResourceDefinitionSpec, CustomResourceDefinitionStatus, CustomResourceDefinitionVersion, CustomResourceSubresourceScale, CustomResourceSubresourceStatus, CustomResourceSubresources, CustomResourceValidation, ExternalDocumentation, JSON, JSONSchemaProps, JSONSchemaPropsOrArray, JSONSchemaPropsOrBool, JSONSchemaPropsOrStringArray, SelectableField, ServiceReference, ValidationRule, WebhookClientConfig, WebhookConversion




__all__ = ['CustomResourceColumnDefinition', 'CustomResourceConversion', 'CustomResourceDefinition', 'CustomResourceDefinitionCondition', 'CustomResourceDefinitionList', 'CustomResourceDefinitionNames', 'CustomResourceDefinitionSpec', 'CustomResourceDefinitionStatus', 'CustomResourceDefinitionVersion', 'CustomResourceSubresourceScale', 'CustomResourceSubresourceStatus', 'CustomResourceSubresources', 'CustomResourceValidation', 'ExternalDocumentation', 'JSON', 'JSONSchemaProps', 'JSONSchemaPropsOrArray', 'JSONSchemaPropsOrBool', 'JSONSchemaPropsOrStringArray', 'SelectableField', 'ServiceReference', 'ValidationRule', 'WebhookClientConfig', 'WebhookConversion']

